/***********************************************************************************************************************************
Gz Common
***********************************************************************************************************************************/
#ifndef COMMON_COMPRESS_GZ_COMMON_H
#define COMMON_COMPRESS_GZ_COMMON_H

/***********************************************************************************************************************************
Gz extension
***********************************************************************************************************************************/
#define GZ_EXT                                                      "gz"

/***********************************************************************************************************************************
Constants
***********************************************************************************************************************************/
#define WINDOW_BITS                                                 15
#define WANT_GZ                                                     16

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
// Process gz errors
FN_EXTERN int gzError(int error);

#endif
